@@ -569,11 +569,14 @@ PROT_EnchashDecrypter.prototype.parseRegExps = function(data) {
  * type -url.
  *
  * @param url String to canonicalize
+ * @param opt_collapseSlashes Boolean true if we want to collapse slashes in
+ *        the path
  *
  * @returns String containing the canonicalized url (maximally url-decoded
  *          with hostname normalized, then specially url-encoded)
  */
-PROT_EnchashDecrypter.prototype.getCanonicalUrl = function(url) {
+PROT_EnchashDecrypter.prototype.getCanonicalUrl = function(url,
+                                                        opt_collapseSlashes) {
   var urlUtils = Cc["@mozilla.org/url-classifier/utils;1"]
                  .getService(Ci.nsIUrlClassifierUtils);
   var escapedUrl = urlUtils.canonicalizeURL(url);
@@ -589,6 +592,13 @@ PROT_EnchashDecrypter.prototype.getCanonicalUrl = function(url) {
                   .getService(Ci.nsIIOService);
   var urlObj = ioService.newURI(escapedUrl, null, null);
   urlObj.host = host;
+  if (opt_collapseSlashes) {
+    // Collapse multiple slashes in the path into a single slash.
+    // We end up collapsing slashes in the query string, but it's unlikely
+    // that this would lead to a false positive and it's much simpler to do
+    // this.
+    urlObj.path = urlObj.path.replace(/\/+/g, "/");
+  }
   return urlObj.asciiSpec;
 }
 
@@ -998,19 +1008,18 @@ UrlClassifierTableUrl.inherits(UrlClassifierTable);
  * Look up a URL in a URL table
  */
 UrlClassifierTableUrl.prototype.exists = function(url, callback) {
-  // nsIUrlClassifierUtils.canonicalizeURL is the old way of canonicalizing a
-  // URL.  Unfortunately, it doesn't normalize numeric domains so alternate IP
-  // formats (hex, octal, etc) won't trigger a match.
-  // this.enchashDecrypter_.getCanonicalUrl does the right thing and
-  // normalizes a URL to 4 decimal numbers, but the update server may still be
-  // giving us encoded IP addresses.  So to be safe, we check both cases.
   var urlUtils = Cc["@mozilla.org/url-classifier/utils;1"]
                  .getService(Ci.nsIUrlClassifierUtils);
-  var oldCanonicalized = urlUtils.canonicalizeURL(url);
-  var canonicalized = this.enchashDecrypter_.getCanonicalUrl(url);
-  G_Debug(this, "Looking up: " + url + " (" + oldCanonicalized + " and " +
-                canonicalized + ")");
-  (new ExistsMultiQuerier([oldCanonicalized, canonicalized],
+  // We plan on having the server collapse multiple slashes in the path.
+  // Until this happens, we check both the raw url and the url with multiple
+  // slashes removed.
+  var urls = [
+    this.enchashDecrypter_.getCanonicalUrl(url),
+    this.enchashDecrypter_.getCanonicalUrl(url, true) /* collapse slashes */
+  ];
+
+  G_Debug(this, "Looking up: " + url + " (" + urls + ")");
+  (new ExistsMultiQuerier(urls,
                           this.name,
                           callback)).run();
 }
@@ -1101,7 +1110,7 @@ UrlClassifierTableEnchash.prototype.exists = function(url, callback) {
   // Run the possible domains against the db.
   (new EnchashMultiQuerier(possible, this.name, callback, url)).run();
 }
-//@line 46 "/usr/obj/ports/mozilla-thunderbird-2.0.0.6/mozilla/toolkit/components/url-classifier/src/nsUrlClassifierTable.js"
+//@line 46 "/usr/obj/ports/mozilla-thunderbird-2.0.0.12/mozilla/toolkit/components/url-classifier/src/nsUrlClassifierTable.js"
 
 var modScope = this;
 function Init() {
