@@ -1,4 +1,4 @@
-//@line 43 "/usr/obj/ports/mozilla-thunderbird-2.0.0.6/mozilla/mail/base/content/msgMail3PaneWindow.js"
+//@line 43 "/usr/obj/ports/mozilla-thunderbird-2.0.0.12/mozilla/mail/base/content/msgMail3PaneWindow.js"
 
 /* This is where functions related to the 3 pane window are kept */
 
@@ -847,7 +847,7 @@ function delayedOnLoadMessenger()
     gSearchEmailAddress = (window.arguments.length > 2) ? window.arguments[2] : null;
   }
 
-//@line 892 "/usr/obj/ports/mozilla-thunderbird-2.0.0.6/mozilla/mail/base/content/msgMail3PaneWindow.js"
+//@line 892 "/usr/obj/ports/mozilla-thunderbird-2.0.0.12/mozilla/mail/base/content/msgMail3PaneWindow.js"
   var nsIShellService = Components.interfaces.nsIShellService;
   var shellService;
   var defaultAccount;
@@ -863,7 +863,7 @@ function delayedOnLoadMessenger()
       && !shellService.isDefaultClient(true, nsIShellService.MAIL))
     window.openDialog("chrome://messenger/content/defaultClientDialog.xul", "DefaultClient", 
                       "modal,centerscreen,chrome,resizable=no");
-//@line 908 "/usr/obj/ports/mozilla-thunderbird-2.0.0.6/mozilla/mail/base/content/msgMail3PaneWindow.js"
+//@line 908 "/usr/obj/ports/mozilla-thunderbird-2.0.0.12/mozilla/mail/base/content/msgMail3PaneWindow.js"
 
   setTimeout("loadStartFolder(gStartFolderUri);", 0);
 
@@ -998,6 +998,8 @@ function loadStartFolder(initialUri)
       // this is the case where we're trying to auto-subscribe to a folder.
       if (initialUri && !startFolder.parent)
       {
+        // hack to force display of thread pane.
+        ShowingThreadPane();
         messenger.loadURL(window, initialUri);
         return;
       }
