@@ -1,4 +1,4 @@
-//@line 38 "/usr/obj/ports/mozilla-thunderbird-2.0.0.6/mozilla/mail/components/preferences/changeaction.js"
+//@line 38 "/usr/obj/i386/mozilla-thunderbird-2.0.0.12/mozilla/mail/components/preferences/changeaction.js"
 
 var gChangeActionDialog = {
   _item             : null,
@@ -64,7 +64,7 @@ var gChangeActionDialog = {
     // We don't let users open .exe files or random binary data directly 
     // from the browser at the moment because of security concerns. 
     var mimeType = this._item.mimeInfo.MIMEType;
-    if (mimeType == "application/object-stream" ||
+    if (mimeType == "application/octet-stream" ||
         mimeType == "application/x-msdownload") {
       document.getElementById("openApplication").disabled = true;
       document.getElementById("openDefault").disabled = true;
